local MM = GetAddOnMetadata("MarkMe", "Title")
local Name, MMNS = ...;
local MMVersionNum = GetAddOnMetadata("MarkMe", "Version")

DEFAULT_CHAT_FRAME:AddMessage(MM.. ' v.' ..MMVersionNum.. ' is loaded.')
DEFAULT_CHAT_FRAME:AddMessage(MM..' Use /mm options to open options, use /mm reset to reset to default')

local MMSettings_Default =
{
	locked_skull = false,
	locked_cross = false,
	locked_square = false,
	locked_moon = false,
	locked_triangle = false,
	locked_diamond = false,
	locked_circle = true,
	locked_star = true,
	skull_line = "Skull - kill first",
	cross_line = "Cross - kill second",
	square_line = "Square - trap",
	moon_line = "Moon - sheep",
	triangle_line = "Triangle - fear",
	diamond_line = "Diamond - sap",
	circle_line = "Circle - ",
	star_line = "Star - ",
	mainFrameScale = 1,
	lock_frame = false,
	show_cog = true,
	use_fade = false,
	fade_num = 0.2,
	is_vertical = false,
	current_theme = "Default",
	show_readycheck = true,
	show_announce = true,
	current_layout = "Horizontal"
}


local MMMarks_Struct =
{
[1] = {Name = "Skull", TexCoord = {0.75,1,0.25,0.5}, RaidMarkNum = 8},
[2] = {Name = "Cross", TexCoord = {0.5,0.75,0.25,0.5}, RaidMarkNum = 7},
[3] = {Name = "Square", TexCoord = {0.25,0.5,0.25,0.5}, RaidMarkNum = 6},
[4] = {Name = "Moon", TexCoord = {0,0.25,0.25,0.5}, RaidMarkNum = 5},
[5] = {Name = "Triangle", TexCoord = {0.75,1,0,0.25}, RaidMarkNum = 4},
[6] = {Name = "Diamond", TexCoord = {0.5,0.75,0,0.25}, RaidMarkNum = 3},
[7] = {Name = "Circle", TexCoord = {0.25,0.5,0,0.25}, RaidMarkNum = 2},
[8] = {Name = "Star", TexCoord = {0,0.25,0,0.25}, RaidMarkNum = 1},
}

MMGLOBALS = {}

local enable_readycheck = false
local enable_announcer = false

------------- Refresh bar and anchors -------------
function RefreshBar ()
	if MMSettings.show_readycheck then
		ReadycheckFrame:Show()
	else
		ReadycheckFrame:Hide()
	end

	if MMSettings.show_announce then
		AnnounceFrame:Show()
	else
		AnnounceFrame:Hide()
	end
	for key, value in pairs(MMMarks_Struct) do
		local Curr = _G["Toggle" ..value.Name]
		if MMSettings["locked_" ..value.Name:lower()] and MMSettings.show_announce then
			Curr:Show()
		else
			Curr:Hide()
		end
	end
end

------------- Main Frame -------------
mainFrame = CreateFrame("Frame", "mainFrame", UIParent, BackdropTemplateMixin and "BackdropTemplate")
mainFrame:SetBackdrop(MMNS.defaultBackdrop)
mainFrame:SetBackdropColor(0.1,0.1,0.1,0.7)
mainFrame:SetMovable(true)
mainFrame:SetPoint("CENTER", UIParent, "CENTER")
mainFrame:SetClampedToScreen(true)
mainFrame:SetScript("OnMouseDown", function(self,button) if (button=="LeftButton" and MMSettings.lock_frame ~= true) then mainFrame:StartMoving() end end)

------------- Icon Frame -------------
local iconFrame = CreateFrame("Frame", "iconFrame", mainFrame)
iconFrame:SetScript("OnMouseDown", function(self,button) if (button=="LeftButton" and MMSettings.lock_frame ~= true) then mainFrame:StartMoving() end end)
iconFrame:SetScript("OnMouseUp", function(self) mainFrame:StopMovingOrSizing() end)
iconFrame:SetScript('OnEnter', function(self,button) MM_HighlightMe("highlight") end)
iconFrame:SetScript('OnLeave', function(self,button) MM_HighlightMe("fade") end)

------------- Readycheck Frame -------------
local ReadycheckFrame = CreateFrame("Frame", "ReadycheckFrame", mainFrame, BackdropTemplateMixin and "BackdropTemplate")
ReadycheckFrame:SetBackdrop(MMNS.defaultBackdrop)
ReadycheckFrame:SetBackdropColor(0.1,0.1,0.1,0.7)
ReadycheckFrame:SetMovable(true)
ReadycheckFrame:SetSize(40, 40)
ReadycheckFrame:SetScript("OnMouseDown", function(self,button) if (button=="LeftButton" and MMSettings.lock_frame ~= true) then mainFrame:StartMoving() end end)
ReadycheckFrame:SetScript("OnMouseUp", function(self) mainFrame:StopMovingOrSizing() end)
ReadycheckFrame:SetScript('OnEnter', function(self,button) MM_HighlightMe("highlight") end)
ReadycheckFrame:SetScript('OnLeave', function(self,button) MM_HighlightMe("fade") end)

------------- Announce Frame -------------
local AnnounceFrame = CreateFrame("Frame", "AnnounceFrame", mainFrame, BackdropTemplateMixin and "BackdropTemplate")
AnnounceFrame:SetBackdrop(MMNS.defaultBackdrop)
AnnounceFrame:SetBackdropColor(0.1,0.1,0.1,0.7)
AnnounceFrame:SetMovable(true)
AnnounceFrame:SetSize(40, 40)
AnnounceFrame:SetScript("OnMouseDown", function(self,button) if (button=="LeftButton" and	 MMSettings.lock_frame ~= true) then mainFrame:StartMoving() end end)
AnnounceFrame:SetScript("OnMouseUp", function(self) mainFrame:StopMovingOrSizing() end)
AnnounceFrame:SetScript('OnEnter', function(self,button) MM_HighlightMe("highlight") end)
AnnounceFrame:SetScript('OnLeave', function(self,button) MM_HighlightMe("fade") end)

------------- Mark Buttons, Toggle buttons -------------
for key, value in pairs(MMMarks_Struct) do
	local IconMark = CreateFrame("Button", "icon" .. value.Name, iconFrame)
	IconMark:SetSize(25,25)
	IconMark:SetNormalTexture("interface\\targetingframe\\ui-raidtargetingicons")
	IconMark:GetNormalTexture():SetTexCoord(value.TexCoord[1], value.TexCoord[2], value.TexCoord[3], value.TexCoord[4])
	IconMark:SetScript("OnClick", function(self) SetRaidTargetIcon("target", value.RaidMarkNum) end)
	IconMark:SetScript("OnMouseDown", function(self,button) if (button=="RightButton") then Toggle_Announce(value.Name) _G["Announce_"..value.Name.."_Toggle"]:SetChecked(not MMSettings["locked_" ..value.Name:lower()]) end end)
	IconMark:SetScript('OnEnter', function(self,button) MM_HighlightMe("highlight") end)
	IconMark:SetScript('OnLeave', function(self,button) MM_HighlightMe("fade") end)
	
	local ToggleButton = CreateFrame("Button", "Toggle" .. value.Name, iconFrame)
	ToggleButton:SetSize(10,10)
	ToggleButton:SetPoint("CENTER", IconMark, "BOTTOM",0,-4)
	ToggleButton:SetNormalTexture("interface\\GLUES\\LOGIN\\Glues-CheckBox-Check")
end 

------------- Readycheck Button -------------
local Readycheck = CreateFrame("Button", "Readycheck", ReadycheckFrame)
Readycheck:SetSize(25,25)
Readycheck:SetPoint("CENTER", ReadycheckFrame , "CENTER", 0, 0)
Readycheck:SetNormalTexture("Interface\\RAIDFRAME\\ReadyCheck-Ready")
Readycheck:SetScript("OnClick", function(self) DoReadyCheck() end)
Readycheck:SetScript('OnEnter', function(self,button) MM_HighlightMe("highlight") end)
Readycheck:SetScript('OnLeave', function(self,button) MM_HighlightMe("fade") end)

------------- Settings Button -------------
local SettingsIcon = CreateFrame("Button", "SettingsIcon", mainFrame)
SettingsIcon:SetSize(14,14)
SettingsIcon:SetPoint("CENTER", iconFrame , "BOTTOMRIGHT", 0, -3)
SettingsIcon:SetNormalTexture("Interface\\GossipFrame\\BinderGossipIcon")
SettingsIcon:SetScript("OnClick", function(self) OpenSettings() end)
SettingsIcon:SetScript('OnEnter', function(self,button) MM_HighlightMe("highlight") end)
SettingsIcon:SetScript('OnLeave', function(self,button) MM_HighlightMe("fade") end)

------------- Announce Button -------------
local announceIcon = CreateFrame("Button", "announceIcon", AnnounceFrame)
announceIcon:SetSize(35,35)
announceIcon:SetPoint("CENTER", AnnounceFrame , "CENTER", 0, -2)
announceIcon:SetNormalTexture("Interface\\FriendsFrame\\UI-Toast-BroadcastIcon")
announceIcon:SetScript("OnClick", function(self) Announce() end)
announceIcon:SetScript('OnEnter', function(self,button) MM_HighlightMe("highlight") end)
announceIcon:SetScript('OnLeave', function(self,button) MM_HighlightMe("fade") end)

------------- Chat Parser -------------
local function MMCmd(msg, editbox)
	if (msg=="reset") then
		SetDefaultSettings()
		mainFrame:ClearAllPoints()
		mainFrame:SetPoint("CENTER");
		Init()
		PartyChecker()
	end
	if (msg=="options" or msg=="settings" or msg =="") then
		OpenSettings()
	end
	if (msg=="help") then
		DEFAULT_CHAT_FRAME:AddMessage("Use /mm options to open options, use /mm reset to reset to default")
	end
end

SLASH_MM1= '/mm'
SlashCmdList["MM"] = MMCmd

------------- OPs -------------
function Init()
	if (MMSettings == nil) then 
	SetDefaultSettings()
	else 
	FIXVars() ----- Using this to fix settings for additional vars in new versions
	end
	LoadSettings()
	Change_Layout()
	RefreshBar()
	PartyChecker()
	Change_Theme(MMSettings.current_theme)
	CogRefresh()
	FadeInit()	
end

function SetDefaultSettings()
	MMSettings = MMSettings_Default	
end

function FIXVars() ----- Using this to fix settings for additional vars in new versions
	if (MMSettings.mainFrameScale == nil) then
		MMSettings.mainFrameScale = 1
	end
	if (MMSettings.lock_frame == nil) then
		MMSettings.lock_frame = false
	end
	if (MMSettings.show_cog == nil) then
		MMSettings.show_cog = true
	end
	if (MMSettings.fade_num == nil) then
		MMSettings.fade_num = 0.2
	end
	if (MMSettings.current_theme == nil) then
		MMSettings.current_theme = "Default"
	end
		if (MMSettings.current_layout == nil) then
		MMSettings.current_layout = "Horizontal"
	end
	if (MMSettings.show_readycheck == nil) then
		MMSettings.show_readycheck = true
	end
	if (MMSettings.show_announce == nil) then
		MMSettings.show_announce = true
	end
	---other vars watchers go here
end

function LoadSettings()
	Lock_Toggle:SetChecked(MMSettings.lock_frame)
	Cog_Toggle:SetChecked(MMSettings.show_cog)
	
	UIDropDownMenu_Initialize(Theme_Dropdown, function(self, level, _)
			local ThemeInfo = UIDropDownMenu_CreateInfo()
			for key, val in pairs(MMNS.Themes_Struct) do
				ThemeInfo.text = key;
				ThemeInfo.checked = false
				ThemeInfo.menuList= key
				ThemeInfo.hasArrow = false
				ThemeInfo.func = function(On_Select)
					UIDropDownMenu_SetSelectedValue(Theme_Dropdown, On_Select.value, On_Select.value)
					UIDropDownMenu_SetText(Theme_Dropdown, On_Select.value)
					On_Select.checked = true
					Change_Theme(On_Select.value)
				end
				UIDropDownMenu_AddButton(ThemeInfo)
			end
		end)
	UIDropDownMenu_SetSelectedValue(Theme_Dropdown, MMSettings.current_theme, MMSettings.current_theme)
	
	UIDropDownMenu_Initialize(Layout_Dropdown, function(self, level, _)
			local LayoutInfo = UIDropDownMenu_CreateInfo()
			for key, val in pairs(MMNS.Layout_Struct) do
				LayoutInfo.text = key;
				LayoutInfo.checked = false
				LayoutInfo.menuList= key
				LayoutInfo.hasArrow = false
				LayoutInfo.func = function(On_Select)
					UIDropDownMenu_SetSelectedValue(Layout_Dropdown, On_Select.value, On_Select.value)
					UIDropDownMenu_SetText(Layout_Dropdown, On_Select.value)
					On_Select.checked = true
					MMSettings.current_layout = Layout
					Change_Layout(On_Select.value)
				end
				UIDropDownMenu_AddButton(LayoutInfo)
			end
		end)
	UIDropDownMenu_SetSelectedValue(Layout_Dropdown, MMSettings.current_layout, MMSettings.current_layout)
	
	getglobal(Fade_Slider:GetName().."Text"):SetText(MM .." fade: "..math.floor((MMSettings.fade_num*100)).."%")	
		Fade_Slider:SetValue(MMSettings.fade_num)
	getglobal(Scale_Slider:GetName().."Text"):SetText(MM .." scale: "..math.floor((MMSettings.mainFrameScale*100)).."%")	
		Scale_Slider:SetValue(MMSettings.mainFrameScale)
		mainFrame:SetScale(MMSettings.mainFrameScale);
	Readycheck_Toggle:SetChecked(MMSettings.show_readycheck)
	Show_Announcer_Toggle:SetChecked(MMSettings.show_announce)

	for key, value in pairs(MMMarks_Struct) do
		local Curr = _G["Toggle" ..value.Name]
		if MMSettings["locked_" ..value.Name:lower()] and MMSettings.show_announce then
			Curr:Show()
		else
			Curr:Hide()
		end
		local Ref = _G["Announce_" .. value.Name .. "_Toggle"]
		Ref:SetChecked(not MMSettings["locked_" ..value.Name:lower()])
		local Ref_Line = _G["Announce_" .. value.Name .. "_Msg"]
		Ref_Line:SetText(MMSettings[value.Name:lower().."_line"])
	end
end

function FadeInit()
		MM_HighlightMe("fade", nil)
end

function CogRefresh()
	if(MMSettings.show_cog) then 
		SettingsIcon:Show()
	else
		SettingsIcon:Hide()
	end
end

function Update_Toggle(toggle)
	local Curr = _G["Toggle" ..toggle]
	if(MMSettings["locked_" ..toggle:lower()] and MMSettings.show_announce) then
		Curr:Show()
	else
		Curr:Hide()
	end
end

function Toggle_Announce(toggle)
		MMSettings["locked_" ..toggle:lower()] = not MMSettings["locked_" ..toggle:lower()]
	Update_Toggle(toggle)
end

----------------- Party Checker ----------
function PartyChecker()
	if MMSettings.Show_Readycheck then
		if (IsInGroup()) then --in party
				if (IsInRaid()) then -- in raid
					if (UnitIsGroupLeader("player") or UnitIsGroupAssistant("player")) then
						Readycheck:SetAlpha(1)
						AnnounceFrame:SetAlpha(1)
						enable_readycheck = true
						enable_announcer = true
						Readycheck:SetEnabled(true)
						announceIcon:SetEnabled(true)
					else
						Readycheck:SetAlpha(0.25)
						AnnounceFrame:SetAlpha(0.25)
						enable_readycheck = false
						enable_announcer = false
						Readycheck:SetEnabled(false)
						announceIcon:SetEnabled(false)
					end
				else -- IN A PARTY
					if (UnitIsGroupLeader("player")) then
						Readycheck:SetAlpha(1)
						AnnounceFrame:SetAlpha(1)
						enable_readycheck = true
						enable_announcer = true
						Readycheck:SetEnabled(true)
						announceIcon:SetEnabled(true)
					else
						Readycheck:SetAlpha(0.25)
						AnnounceFrame:SetAlpha(0.25)
						enable_readycheck = false
						enable_announcer = false
						Readycheck:SetEnabled(false)
						announceIcon:SetEnabled(false)
					end
				end
			else --solo
				Readycheck:SetAlpha(0.25)
				AnnounceFrame:SetAlpha(1)
				enable_readycheck = false
				enable_announcer = true
				Readycheck:SetEnabled(false)
				announceIcon:SetEnabled(true)
			end	   
	end
end

function OpenSettings ()
InterfaceOptionsFrame_OpenToCategory(MarkMeOptions.panel)
end


function Announce ()
if (MMSettings.locked_skull and MMSettings.locked_cross and MMSettings.locked_square and MMSettings.locked_moon and	MMSettings.locked_triangle and MMSettings.locked_diamond and MMSettings.locked_circle and MMSettings.locked_star) then
	print ("No marks set for announce")	
	else
	if IsInGroup() then
			if IsInRaid() then 
				if UnitIsGroupLeader("player") or UnitIsGroupAssistant("player") then		-- ABLE TO MARK
					SendChatMessage(AnnounceComposer(), "RAID", nil) 
				end
			else
				SendChatMessage(AnnounceComposer(), "PARTY", nil) 
			end	
		else
			print ("Preview in solo mode. Your message won't be sent")
			print (AnnounceComposer())
		end
	end
end

function AnnounceComposer()
local AnnounceString = ""
	if (MMSettings.locked_skull ~= true)  then
		AnnounceString = MMSettings.skull_line
	end
	if (MMSettings.locked_cross ~= true)  then
		if (AnnounceString ~= "") then
		AnnounceString = (AnnounceString.. ", " ..MMSettings.cross_line)
		else
		AnnounceString = MMSettings.cross_line
		end
	end
	if (MMSettings.locked_square ~= true)  then
		if (AnnounceString ~= "") then
		AnnounceString = (AnnounceString.. ", " ..MMSettings.square_line)
		else
		AnnounceString = MMSettings.square_line
		end
	end
	if (MMSettings.locked_moon ~= true)  then
		if (AnnounceString ~= "") then
		AnnounceString = (AnnounceString.. ", " ..MMSettings.moon_line)
		else
		AnnounceString = MMSettings.moon_line
		end
	end
	if (MMSettings.locked_triangle ~= true)  then
		if (AnnounceString ~= "") then
		AnnounceString = (AnnounceString.. ", " ..MMSettings.triangle_line)
		else
		AnnounceString = MMSettings.triangle_line
		end
	end
	if (MMSettings.locked_diamond ~= true)  then
		if (AnnounceString ~= "") then
		AnnounceString = (AnnounceString.. ", " ..MMSettings.diamond_line)
		else
		AnnounceString = MMSettings.diamond_line
		end
	end
	if (MMSettings.locked_circle ~= true)  then
		if (AnnounceString ~= "") then
		AnnounceString = (AnnounceString.. ", " ..MMSettings.circle_line)
		else
		AnnounceString = MMSettings.circle_line
		end
	end
	if (MMSettings.locked_star ~= true)  then
		if (AnnounceString ~= "") then
		AnnounceString = (AnnounceString.. ", " ..MMSettings.star_line)
		else
		AnnounceString = MMSettings.star_line
		end
	end
return (AnnounceString)
end

function Change_Theme(Theme)
mainFrame:SetBackdrop(MMNS.Themes_Struct[Theme].Backdrop)
mainFrame:SetBackdropColor(MMNS.Themes_Struct[Theme].BackdropColor[1], MMNS.Themes_Struct[Theme].BackdropColor[2], MMNS.Themes_Struct[Theme].BackdropColor[3], MMNS.Themes_Struct[Theme].BackdropColor[4])

ReadycheckFrame:SetBackdrop(MMNS.Themes_Struct[Theme].Backdrop)
ReadycheckFrame:SetBackdropColor(MMNS.Themes_Struct[Theme].BackdropColor[1], MMNS.Themes_Struct[Theme].BackdropColor[2], MMNS.Themes_Struct[Theme].BackdropColor[3], MMNS.Themes_Struct[Theme].BackdropColor[4])

AnnounceFrame:SetBackdrop(MMNS.Themes_Struct[Theme].Backdrop)
AnnounceFrame:SetBackdropColor(MMNS.Themes_Struct[Theme].BackdropColor[1], MMNS.Themes_Struct[Theme].BackdropColor[2], MMNS.Themes_Struct[Theme].BackdropColor[3], MMNS.Themes_Struct[Theme].BackdropColor[4])

MMSettings.current_theme = Theme
end

function Change_Layout(Layout)
	if (Layout == nil) then
		Layout = MMSettings.current_layout
	end
	mainFrame:SetSize(unpack(MMNS.Layout_Struct[Layout].Mainframe_Size))
	
	iconFrame:SetSize(unpack(MMNS.Layout_Struct[Layout].Mainframe_Size))
	iconFrame:ClearAllPoints()
	iconFrame:SetPoint(MMNS.Layout_Struct[Layout].Icon_Frame_Rel_Points[1], mainFrame, MMNS.Layout_Struct[Layout].Icon_Frame_Rel_Points[2])

	ReadycheckFrame:ClearAllPoints()
	ReadycheckFrame:SetPoint(MMNS.Layout_Struct[Layout].Readycheck_Frame_Rel_Points[1], mainFrame, MMNS.Layout_Struct[Layout].Readycheck_Frame_Rel_Points[2])

	AnnounceFrame:ClearAllPoints()
	AnnounceFrame:SetPoint(MMNS.Layout_Struct[Layout].Announce_Frame_Rel_Points[1], mainFrame, MMNS.Layout_Struct[Layout].Announce_Frame_Rel_Points[2])

	iconSkull:ClearAllPoints()
	iconSkull:SetPoint(MMNS.Layout_Struct[Layout].Skull_Rel_Points[1], iconFrame, MMNS.Layout_Struct[Layout].Skull_Rel_Points[2], unpack(MMNS.Layout_Struct[Layout].Skull_Rel_Points[3]))
	iconCross:ClearAllPoints()
	iconCross:SetPoint(MMNS.Layout_Struct[Layout].Cross_Rel_Points[1], iconSkull, MMNS.Layout_Struct[Layout].Cross_Rel_Points[2], unpack(MMNS.Layout_Struct[Layout].Cross_Rel_Points[3]))
	iconSquare:ClearAllPoints()
	iconSquare:SetPoint(MMNS.Layout_Struct[Layout].Square_Rel_Points[1], iconCross, MMNS.Layout_Struct[Layout].Square_Rel_Points[2], unpack(MMNS.Layout_Struct[Layout].Square_Rel_Points[3]))
	iconMoon:ClearAllPoints()
	iconMoon:SetPoint(MMNS.Layout_Struct[Layout].Moon_Rel_Points[1], iconSquare, MMNS.Layout_Struct[Layout].Moon_Rel_Points[2], unpack(MMNS.Layout_Struct[Layout].Moon_Rel_Points[3]))
	iconTriangle:ClearAllPoints()
	iconTriangle:SetPoint(MMNS.Layout_Struct[Layout].Triangle_Rel_Points[1], iconMoon, MMNS.Layout_Struct[Layout].Triangle_Rel_Points[2], unpack(MMNS.Layout_Struct[Layout].Triangle_Rel_Points[3]))
	iconDiamond:ClearAllPoints()
	iconDiamond:SetPoint(MMNS.Layout_Struct[Layout].Diamond_Rel_Points[1], iconTriangle, MMNS.Layout_Struct[Layout].Diamond_Rel_Points[2], unpack(MMNS.Layout_Struct[Layout].Diamond_Rel_Points[3]))
	iconCircle:ClearAllPoints()
	iconCircle:SetPoint(MMNS.Layout_Struct[Layout].Circle_Rel_Points[1], iconDiamond, MMNS.Layout_Struct[Layout].Circle_Rel_Points[2], unpack(MMNS.Layout_Struct[Layout].Circle_Rel_Points[3]))
	iconStar:ClearAllPoints()
	iconStar:SetPoint(MMNS.Layout_Struct[Layout].Star_Rel_Points[1], iconCircle, MMNS.Layout_Struct[Layout].Star_Rel_Points[2], unpack(MMNS.Layout_Struct[Layout].Star_Rel_Points[3]))
end

------------- Settings  OPs -------------
function MM_Lock_Frame()
	MMSettings.lock_frame = not MMSettings.lock_frame
end

function MM_Options_Cog_Toogle()
	MMSettings.show_cog =  not MMSettings.show_cog
	CogRefresh()
end

function MM_Show_Readycheck_Toggle()
	MMSettings.show_readycheck =  not MMSettings.show_readycheck
	RefreshBar()
end

function MM_Show_Announce_Toggle()
	MMSettings.show_announce =  not MMSettings.show_announce
	RefreshBar()
end

function MM_Preview_Fade()
	MM_HighlightMe("false", Fade_Slider:GetValue())
end

function MM_Update_Fade()
	MMSettings.fade_num = (Fade_Slider:GetValue())
end

function MM_Preview_Scale()		
    mainFrame:SetScale(Scale_Slider:GetValue())
end

function MM_Update_Scale()
	mainFrame:SetScale(Scale_Slider:GetValue())
    MMSettings.mainFrameScale = (Scale_Slider:GetValue())
end

function MM_Save_Line(name, text)
MMSettings[name:lower().."_line"] = (text)
end

function MM_HighlightMe (state, override)
		if (state == "highlight") then
		mainFrame:SetAlpha(1)
			-- if (enable_readycheck) then
			-- ReadycheckFrame:SetAlpha(1)
			-- end
			-- if (enable_announcer) then
			-- AnnounceFrame:SetAlpha(1)
			-- end
		else
			if override then
				mainFrame:SetAlpha(override)
			else
				mainFrame:SetAlpha(MMSettings.fade_num)
			end
		end
end

-- ------------- Events -------------
local MM_OnUpdate = CreateFrame("Frame")
MM_OnUpdate:RegisterEvent("ADDON_LOADED")
MM_OnUpdate:RegisterEvent("GROUP_ROSTER_UPDATE")


MM_OnUpdate:SetScript("OnEvent", function(self,event,addon,...)
	if (event=="ADDON_LOADED" and addon=="MarkMe") then
		Init()
		PartyChecker()
	end	
	if (event=="GROUP_ROSTER_UPDATE") then
		PartyChecker()
    end
end
)